# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ErrorEntity
from ..models import ItemReferenceInfo

from ..operations.utilities import GetItemReferences


@same_doc_as(GetItemReferences)
def get_item_references(
    item_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get season pass ecommerce item references (getItemReferences)

    This API is used to get season pass ecommerce item references.

    Other detail info:

      * Returns : item references data

    Properties:
        url: /seasonpass/admin/namespaces/{namespace}/seasons/item/references

        method: GET

        tags: ["Utilities"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        item_id: (itemId) REQUIRED str in query

    Responses:
        200: OK - ItemReferenceInfo (successful operation)

        400: Bad Request - ErrorEntity (20026: publisher namespace not allowed | 20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetItemReferences.create(
        item_id=item_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetItemReferences)
async def get_item_references_async(
    item_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get season pass ecommerce item references (getItemReferences)

    This API is used to get season pass ecommerce item references.

    Other detail info:

      * Returns : item references data

    Properties:
        url: /seasonpass/admin/namespaces/{namespace}/seasons/item/references

        method: GET

        tags: ["Utilities"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        item_id: (itemId) REQUIRED str in query

    Responses:
        200: OK - ItemReferenceInfo (successful operation)

        400: Bad Request - ErrorEntity (20026: publisher namespace not allowed | 20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetItemReferences.create(
        item_id=item_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Seasonpass Service."""

__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._export import export_season
from ._export import export_season_async

from ._pass_ import create_pass
from ._pass_ import create_pass_async
from ._pass_ import delete_pass
from ._pass_ import delete_pass_async
from ._pass_ import get_pass
from ._pass_ import get_pass_async
from ._pass_ import grant_user_pass
from ._pass_ import grant_user_pass_async
from ._pass_ import query_passes
from ._pass_ import query_passes_async
from ._pass_ import update_pass
from ._pass_ import update_pass_async

from ._reward import create_reward
from ._reward import create_reward_async
from ._reward import delete_reward
from ._reward import delete_reward_async
from ._reward import get_reward
from ._reward import get_reward_async
from ._reward import public_bulk_claim_user_rewards
from ._reward import public_bulk_claim_user_rewards_async
from ._reward import public_claim_user_reward
from ._reward import public_claim_user_reward_async
from ._reward import query_rewards
from ._reward import query_rewards_async
from ._reward import update_reward
from ._reward import update_reward_async

from ._season import bulk_get_user_season_progression
from ._season import bulk_get_user_season_progression_async
from ._season import check_season_purchasable
from ._season import check_season_purchasable_async
from ._season import clone_season
from ._season import clone_season_async
from ._season import create_season
from ._season import create_season_async
from ._season import delete_season
from ._season import delete_season_async
from ._season import exists_any_pass_by_pass_codes
from ._season import exists_any_pass_by_pass_codes_async
from ._season import get_current_season
from ._season import get_current_season_async
from ._season import get_current_user_season_progression
from ._season import get_current_user_season_progression_async
from ._season import get_full_season
from ._season import get_full_season_async
from ._season import get_season
from ._season import get_season_async
from ._season import get_user_participated_seasons
from ._season import get_user_participated_seasons_async
from ._season import get_user_season
from ._season import get_user_season_async
from ._season import public_get_current_season
from ._season import public_get_current_season_async
from ._season import public_get_current_user_season
from ._season import public_get_current_user_season_async
from ._season import public_get_user_season
from ._season import public_get_user_season_async
from ._season import publish_season
from ._season import publish_season_async
from ._season import query_seasons
from ._season import query_seasons_async
from ._season import query_user_exp_grant_history
from ._season import query_user_exp_grant_history_async
from ._season import query_user_exp_grant_history_tag
from ._season import query_user_exp_grant_history_tag_async
from ._season import reset_user_season
from ._season import reset_user_season_async
from ._season import retire_season
from ._season import retire_season_async
from ._season import unpublish_season
from ._season import unpublish_season_async
from ._season import update_season
from ._season import update_season_async

from ._tier import create_tier
from ._tier import create_tier_async
from ._tier import delete_tier
from ._tier import delete_tier_async
from ._tier import grant_user_exp
from ._tier import grant_user_exp_async
from ._tier import grant_user_tier
from ._tier import grant_user_tier_async
from ._tier import query_tiers
from ._tier import query_tiers_async
from ._tier import reorder_tier
from ._tier import reorder_tier_async
from ._tier import update_tier
from ._tier import update_tier_async

from ._utilities import get_item_references
from ._utilities import get_item_references_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Seasonpass Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ItemReference(Model):
    """A DTO object for item references. (ItemReference)

    Properties:
        module: (module) OPTIONAL str

        references: (references) OPTIONAL List[Dict[str, Any]]
    """

    # region fields

    module: str  # OPTIONAL
    references: List[Dict[str, Any]]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_module(self, value: str) -> ItemReference:
        self.module = value
        return self

    def with_references(self, value: List[Dict[str, Any]]) -> ItemReference:
        self.references = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "module"):
            result["module"] = str(self.module)
        elif include_empty:
            result["module"] = ""
        if hasattr(self, "references"):
            result["references"] = [
                {str(k1): v1 for k1, v1 in i0.items()} for i0 in self.references
            ]
        elif include_empty:
            result["references"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        module: Optional[str] = None,
        references: Optional[List[Dict[str, Any]]] = None,
        **kwargs,
    ) -> ItemReference:
        instance = cls()
        if module is not None:
            instance.module = module
        if references is not None:
            instance.references = references
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ItemReference:
        instance = cls()
        if not dict_:
            return instance
        if "module" in dict_ and dict_["module"] is not None:
            instance.module = str(dict_["module"])
        elif include_empty:
            instance.module = ""
        if "references" in dict_ and dict_["references"] is not None:
            instance.references = [
                {str(k1): v1 for k1, v1 in i0.items()} for i0 in dict_["references"]
            ]
        elif include_empty:
            instance.references = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ItemReference]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ItemReference]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ItemReference, List[ItemReference], Dict[Any, ItemReference]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "module": "module",
            "references": "references",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "module": False,
            "references": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Seasonpass Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model
from accelbyte_py_sdk.core import StrEnum


class MethodEnum(StrEnum):
    CURRENCY = "CURRENCY"
    NONE = "NONE"


class ExcessStrategy(Model):
    """Excess strategy (ExcessStrategy)

    Properties:
        method: (method) REQUIRED Union[str, MethodEnum]

        currency: (currency) OPTIONAL str

        percent_per_exp: (percentPerExp) OPTIONAL int
    """

    # region fields

    method: Union[str, MethodEnum]  # REQUIRED
    currency: str  # OPTIONAL
    percent_per_exp: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_method(self, value: Union[str, MethodEnum]) -> ExcessStrategy:
        self.method = value
        return self

    def with_currency(self, value: str) -> ExcessStrategy:
        self.currency = value
        return self

    def with_percent_per_exp(self, value: int) -> ExcessStrategy:
        self.percent_per_exp = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "method"):
            result["method"] = str(self.method)
        elif include_empty:
            result["method"] = Union[str, MethodEnum]()
        if hasattr(self, "currency"):
            result["currency"] = str(self.currency)
        elif include_empty:
            result["currency"] = ""
        if hasattr(self, "percent_per_exp"):
            result["percentPerExp"] = int(self.percent_per_exp)
        elif include_empty:
            result["percentPerExp"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        method: Union[str, MethodEnum],
        currency: Optional[str] = None,
        percent_per_exp: Optional[int] = None,
        **kwargs,
    ) -> ExcessStrategy:
        instance = cls()
        instance.method = method
        if currency is not None:
            instance.currency = currency
        if percent_per_exp is not None:
            instance.percent_per_exp = percent_per_exp
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ExcessStrategy:
        instance = cls()
        if not dict_:
            return instance
        if "method" in dict_ and dict_["method"] is not None:
            instance.method = str(dict_["method"])
        elif include_empty:
            instance.method = Union[str, MethodEnum]()
        if "currency" in dict_ and dict_["currency"] is not None:
            instance.currency = str(dict_["currency"])
        elif include_empty:
            instance.currency = ""
        if "percentPerExp" in dict_ and dict_["percentPerExp"] is not None:
            instance.percent_per_exp = int(dict_["percentPerExp"])
        elif include_empty:
            instance.percent_per_exp = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ExcessStrategy]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ExcessStrategy]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ExcessStrategy, List[ExcessStrategy], Dict[Any, ExcessStrategy]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "method": "method",
            "currency": "currency",
            "percentPerExp": "percent_per_exp",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "method": True,
            "currency": False,
            "percentPerExp": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "method": ["CURRENCY", "NONE"],
        }

    # endregion static methods



# Copyright (c) 2024 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: errors.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Seasonpass Service

from accelbyte_py_sdk.core import ApiError

ERROR_20001 = ApiError(code="20001", message="Unauthorized")
ERROR_20002 = ApiError(code="20002", message="validation error")
ERROR_20026 = ApiError(code="20026", message="publisher namespace not allowed")
ERROR_30141 = ApiError(
    code="30141", message="Store [{storeId}] does not exist in namespace [{namespace}]"
)
ERROR_30142 = ApiError(
    code="30142", message="Published store does not exist in namespace [{namespace}]"
)
ERROR_30341 = ApiError(
    code="30341", message="Item [{itemId}] does not exist in namespace [{namespace}]"
)
ERROR_36141 = ApiError(
    code="36141",
    message="Currency [{currencyCode}] does not exist in namespace [{namespace}]",
)
ERROR_49121 = ApiError(
    code="49121", message="Default language [{language}] required in localizations"
)
ERROR_49122 = ApiError(code="49122", message="Invalid time range")
ERROR_49124 = ApiError(code="49124", message="Manual claim not supported")
ERROR_49141 = ApiError(
    code="49141",
    message="Tier item does not exist in the store of namespace [{namespace}]",
)
ERROR_49142 = ApiError(
    code="49142",
    message="Pass item does not exist in the store of namespace [{namespace}]",
)
ERROR_49143 = ApiError(
    code="49143",
    message="Season [{seasonId}] does not exist in namespace [{namespace}]",
)
ERROR_49144 = ApiError(code="49144", message="Reward [{code}] does not exist")
ERROR_49145 = ApiError(code="49145", message="Pass [{code}] does not exist")
ERROR_49146 = ApiError(code="49146", message="Tier does not exist")
ERROR_49147 = ApiError(code="49147", message="Published season does not exist")
ERROR_49148 = ApiError(code="49148", message="User season does not exist")
ERROR_49171 = ApiError(code="49171", message="Invalid season status [{status}]")
ERROR_49172 = ApiError(code="49172", message="Season is already ended")
ERROR_49173 = ApiError(
    code="49173", message="Reward [{code}] already exists in the season"
)
ERROR_49174 = ApiError(
    code="49174", message="Pass [{code}] already exists in the season"
)
ERROR_49175 = ApiError(
    code="49175", message="Published season already exists in namespace [{namespace}]"
)
ERROR_49176 = ApiError(code="49176", message="Rewards are not provided")
ERROR_49177 = ApiError(code="49177", message="Passes are not provided")
ERROR_49178 = ApiError(code="49178", message="Tiers are not provided")
ERROR_49179 = ApiError(code="49179", message="Reward [{code}] is in use")
ERROR_49180 = ApiError(code="49180", message="Season is already started")
ERROR_49181 = ApiError(code="49181", message="Season has not ended")
ERROR_49182 = ApiError(code="49182", message="Reward is already claimed")
ERROR_49183 = ApiError(
    code="49183", message="Pass item does not match published season pass"
)
ERROR_49184 = ApiError(
    code="49184", message="Tier item does not match published season tier"
)
ERROR_49185 = ApiError(code="49185", message="Season has not started")
ERROR_49186 = ApiError(code="49186", message="Pass already owned")
ERROR_49187 = ApiError(code="49187", message="Exceed max tier count")
ERROR_49188 = ApiError(code="49188", message="Reward is claiming")
ERROR_49189 = ApiError(
    code="49189",
    message="Duplicate season name [{name}] for publishing in namespace [{namespace}]",
)



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: service-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Seasonpass Service."""

__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# export
from .wrappers import export_season
from .wrappers import export_season_async

# pass_
from .wrappers import create_pass
from .wrappers import create_pass_async
from .wrappers import delete_pass
from .wrappers import delete_pass_async
from .wrappers import get_pass
from .wrappers import get_pass_async
from .wrappers import grant_user_pass
from .wrappers import grant_user_pass_async
from .wrappers import query_passes
from .wrappers import query_passes_async
from .wrappers import update_pass
from .wrappers import update_pass_async

# reward
from .wrappers import create_reward
from .wrappers import create_reward_async
from .wrappers import delete_reward
from .wrappers import delete_reward_async
from .wrappers import get_reward
from .wrappers import get_reward_async
from .wrappers import public_bulk_claim_user_rewards
from .wrappers import public_bulk_claim_user_rewards_async
from .wrappers import public_claim_user_reward
from .wrappers import public_claim_user_reward_async
from .wrappers import query_rewards
from .wrappers import query_rewards_async
from .wrappers import update_reward
from .wrappers import update_reward_async

# season
from .wrappers import bulk_get_user_season_progression
from .wrappers import bulk_get_user_season_progression_async
from .wrappers import check_season_purchasable
from .wrappers import check_season_purchasable_async
from .wrappers import clone_season
from .wrappers import clone_season_async
from .wrappers import create_season
from .wrappers import create_season_async
from .wrappers import delete_season
from .wrappers import delete_season_async
from .wrappers import exists_any_pass_by_pass_codes
from .wrappers import exists_any_pass_by_pass_codes_async
from .wrappers import get_current_season
from .wrappers import get_current_season_async
from .wrappers import get_current_user_season_progression
from .wrappers import get_current_user_season_progression_async
from .wrappers import get_full_season
from .wrappers import get_full_season_async
from .wrappers import get_season
from .wrappers import get_season_async
from .wrappers import get_user_participated_seasons
from .wrappers import get_user_participated_seasons_async
from .wrappers import get_user_season
from .wrappers import get_user_season_async
from .wrappers import public_get_current_season
from .wrappers import public_get_current_season_async
from .wrappers import public_get_current_user_season
from .wrappers import public_get_current_user_season_async
from .wrappers import public_get_user_season
from .wrappers import public_get_user_season_async
from .wrappers import publish_season
from .wrappers import publish_season_async
from .wrappers import query_seasons
from .wrappers import query_seasons_async
from .wrappers import query_user_exp_grant_history
from .wrappers import query_user_exp_grant_history_async
from .wrappers import query_user_exp_grant_history_tag
from .wrappers import query_user_exp_grant_history_tag_async
from .wrappers import reset_user_season
from .wrappers import reset_user_season_async
from .wrappers import retire_season
from .wrappers import retire_season_async
from .wrappers import unpublish_season
from .wrappers import unpublish_season_async
from .wrappers import update_season
from .wrappers import update_season_async

# tier
from .wrappers import create_tier
from .wrappers import create_tier_async
from .wrappers import delete_tier
from .wrappers import delete_tier_async
from .wrappers import grant_user_exp
from .wrappers import grant_user_exp_async
from .wrappers import grant_user_tier
from .wrappers import grant_user_tier_async
from .wrappers import query_tiers
from .wrappers import query_tiers_async
from .wrappers import reorder_tier
from .wrappers import reorder_tier_async
from .wrappers import update_tier
from .wrappers import update_tier_async

# utilities
from .wrappers import get_item_references
from .wrappers import get_item_references_async
